Re: cvs: pear /File_Archive package.xml /File_Archive/Archive/Reader MimeList.php
| From: | Greg Beaver | Date: | Tue, 22 Feb 2005 03:49:43 +0000 |
| Subject: | Re: cvs: pear /File_Archive package.xml /File_Archive/Archive/Reader MimeList.php | ||
| References: | 1 | Groups: | php.pear.cvs |
| Request: | Send a blank email to pear-cvs+get-29647@lists.php.net to get a copy of this message | ||
Vincent Lascaux wrote:
vincentlascaux Mon Feb 21 19:32:06 2005 EDTHi Vincent, I'm curious, did you benchmark this change? I've found arrays to be up to 33% faster than big switch statements, but would be curious to see if it is different in your particular situation. GregModified files: /pear/File_Archive/Archive/Reader MimeList.php /pear/File_Archive package.xml Log:+ Add some notes and a changelog to package.xml + Change the MimeList function from an array to a large switch (probably more efficient)